# dbt-exasol
data build tool adapter for exasol
see docs.getdbt.com for more information

# Release 1.0.0

- pyexasol HTTP import csv feature implemented. Optimal performance and compatibility with Exasol CSV parsing
